@@ -11,7 +11,7 @@ use Getopt::Long qw<:config bundling>;
 use List::Util qw<first>;
 use Pod::Usage;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 my %opt;
 
 sub new {
@@ -20,12 +20,22 @@ sub new {
 
 sub run {
     get_options();
+    my ($target, $renderer);
+
     if (defined $opt{file}) {
-        render_file($opt{file}, 'App::Grok::Pod6');
+        ($target, $renderer) = ($opt{file}, 'App::Grok::Pod6');
     }
     else {
-        my $arg = shift @ARGV;
-        find_target($arg);
+        ($target, $renderer) = find_target($ARGV[0]);
+    }
+
+    die "No matching files found for target '$target'" if !-e $target;
+
+    if ($opt{only}) {
+        print "$target\n";
+    }
+    else {
+        render_file($target, $renderer);
     }
 }
 
@@ -34,6 +44,7 @@ sub get_options {
         'F|file=s'   => \$opt{file},
         'f|format=s' => \($opt{format} = 'ansi'),
         'h|help'     => sub { pod2usage(1) },
+        'l|only'     => \$opt{only},
         'T|no-pager' => \$opt{no_pager},
         'v|version'  => sub { print "grok $VERSION\n"; exit },
     ) or pod2usage();
@@ -53,7 +64,7 @@ sub find_target {
     ($target, $renderer) = find_file($arg) if !defined $target;
 
     die "Target '$arg' not recognized\n" if !$target;
-    render_file($target, $renderer);
+    return ($target, $renderer);
 }
 
 sub find_synopsis {
@@ -119,6 +130,8 @@ sub render_file {
 
 1;
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::Grok - Does most of grok's heavy lifting
